@@ -38,7 +38,7 @@ from ae.gui_app import id_of_flow                           # type: ignore
 from ae.kivy_app import FlowPopup                           # type: ignore
 
 
-__version__ = '0.3.8'
+__version__ = '0.3.9'
 
 
 KEY_VAL_SEPARATOR = ": "
@@ -102,7 +102,7 @@ Builder.load_string('''#: set KEY_VAL_SEPARATOR "''' + KEY_VAL_SEPARATOR + '''"
         text: root.text[root.text.index(KEY_VAL_SEPARATOR) + len(KEY_VAL_SEPARATOR):]
         tap_flow_id: root.tap_flow_id
         tap_kwargs: root.tap_kwargs
-        square_fill_ink: app.main_app.flow_path_ink[:3] + (0.18, )
+        square_fill_ink: app.main_app.flow_path_ink[:3] + [0.18]
         square_fill_pos: self.pos
 ''')
 
